  <?php
/**
 * Slider section
 *
 * This is the template for the content of slider section
 *
 * @package Theme Palace
 * @subpackage Kids Education Pro
 * @since Kids Education Pro 1.0
 */
if ( ! function_exists( 'kids_education_pro_add_slider_section' ) ) :
  /**
   * Add slider section
   *
   *@since Kids Education Pro 1.0
   */
  function kids_education_pro_add_slider_section() {

    // Check if slider is enabled on frontpage
    $enable_main_slider = apply_filters( 'kids_education_pro_section_status', true, 'enable_main_slider' );

    if ( true !== $enable_main_slider ) {
      return false;
    }

    // Get slider section details
    $section_details = array();
    $section_details = apply_filters( 'kids_education_pro_filter_slider_section_details', $section_details );

    if ( empty( $section_details ) ) {
      return;
    }

    // Render slider section now.
    kids_education_pro_render_slider_section( $section_details );
  }
endif;
add_action( 'kids_education_pro_primary_content', 'kids_education_pro_add_slider_section', 10 );


if ( ! function_exists( 'kids_education_pro_get_main_slider_section_details' ) ) :
  /**
   * Slider section details.
   *
   * @since Kids Education Pro 1.0
   * @param array $input Slider section details.
   */
   function kids_education_pro_get_main_slider_section_details( $input ) {
      $options = kids_education_pro_get_theme_options(); 

      // Main SLider type
      $main_slider_content_type    = $options['main_slider_type'];
      $no_of_posts = $options['main_slider_no_of_posts'];

      $content = array();

         switch ( $main_slider_content_type ) {

            case 'demo':
                $no_of_posts = 2; // Initialize and overwrite no of posts in demo by 3
                $images = array( 'slider-01.jpg', 'slider-01.jpg'); // An array of demo images

                for ( $index = 0; $index < $no_of_posts ; $index++ ) {
                    $content[$index]['img_array']= array( get_template_directory_uri(). '/assets/uploads/'. $images[$index] );
                    $content[$index]['url']      = '#';
                    $content[$index]['title']    = esc_html__( 'Best Education for Kids Perfectly','kids-education-pro' );
                    $content[$index]['content']  = esc_html__( 'Duis tincidunt lectus eget sem lobortis pellentesque vitae ac augue. Vestibulum pharetra libero ut eget sem lobortis.','kids-education-pro' );
                }
                        
                $input =  $content;
            break;

            case 'category':
                $categories = array();
                $categories = !empty( $options['main_slider_category_type'] ) ? $options['main_slider_category_type'] : array();
                $category = array_filter( $categories );
                
                if ( ! empty( $category ) ) {
                
                    $args = array(
                        'category__in'      => $category,
                        'posts_per_page'    => $no_of_posts,
                    );
                }
            break;

            case 'post':
                $post_list = array();
                for ( $i = 1; $i <= $no_of_posts ; $i++ ) { 
                    $post_id    = ! empty ( $options['post_id_' . $i] ) ? absint( $options['post_id_' . $i] ) : '';
                    $post_list  = array_merge( $post_list, array( $post_id ) );
                }

                if ( ! empty( $post_list ) ) {
                
                    $args = array(
                        'post__in'           => $post_list,
                        'posts_per_page'    => $no_of_posts,
                    );
                }
            break;

            case 'page':
                $page_list = array();
                for ( $i = 1; $i <= $no_of_posts ; $i++ ) { 
                    $page_id    = ! empty ( $options['page_id_' . $i] ) ? absint( $options['page_id_' . $i] ) : '';
                    $page_list  = array_merge( $page_list, array( $page_id ) );
                }

                if ( ! empty( $page_list ) ) {
                
                    $args = array(
                        'post_type'          => 'page',
                        'post__in'           => $page_list,
                        'posts_per_page'     => $no_of_posts,
                    );
                }
            break;

            default:
            break;          
         }
         if( $options['main_slider_type'] != 'demo'  ) :
            
            if( ! empty ( $args ) ) :
                $custom_posts = get_posts( $args );
        
                $i = 0;
                foreach ( $custom_posts as $key => $custom_post ) {
                    $img_array = null;

                    if ( has_post_thumbnail( $custom_post->ID ) ) {
                            $img_array = wp_get_attachment_image_src( get_post_thumbnail_id( $custom_post->ID ), '' );
                    } else {
                            $img_array = array ( get_template_directory_uri() . '/assets/uploads/no-featured-image-1350x550.jpg' );
                    }

                    if ( isset( $img_array ) ) {
                        $content[$i]['img_array'] = $img_array;
                    }

                    $content[$i]['url']      = get_permalink( $custom_post->ID );
                    $content[$i]['title']    = get_the_title( $custom_post->ID );
                    $content[$i]['content']  = kids_education_pro_trim_content( 20, $custom_post );
                $i++;
                }
            endif;
         endif;

         if ( ! empty( $content ) ) {
            $input = $content;
         }
    return $input; 
}
endif;
// Slider section content details.
add_filter( 'kids_education_pro_filter_slider_section_details', 'kids_education_pro_get_main_slider_section_details' );


if ( ! function_exists( 'kids_education_pro_render_slider_section' ) ) :
  /**
   * Start slider section
   *
   * @return string Slider content
   * @since Kids Education Pro 1.0
   *
   */
   function kids_education_pro_render_slider_section( $content_details = array() ) {
        $options          = kids_education_pro_get_theme_options();
        $read_more_button = $options['main_slider_learn_more_text']; 

        $content_type          = $options['main_slider_type'];
        $slider_effect         = ( $options['main_slider_type'] == 'demo' ) ? 'cubic-bezier(0.250, 0.100, 0.250, 1.000)' : $options['slider_content_effect'];
        $slider_control        = ( $options['enable_slider_controls'] == true ) ? 'true' : 'false';
        $slider_dragable       = ( $options['enable_slider_dragable'] == true ) ? 'true' : 'false';
        $slider_pause          = ( $options['slider_pause_on_hover'] == true ) ? 'true' : 'false';
        $slider_divider_enable = $options['slider_divider_enable'];

        if( $content_type == 'demo' ) {
            $data_slick_value = '{"slidesToShow": 1, "slidesToScroll": 1, "infinite": true, "speed": 800, "dots": false, "arrows": true, "autoplay": true, "fade": false }';
        }
        else {
            $data_slick_value = '{"slidesToShow": 1, "slidesToScroll": 1, "infinite": true, "speed": 800, "dots": false, "autoplay": true, "pauseOnHover":'. esc_attr( $slider_pause ).', "arrows": '. esc_attr( $slider_control ).', "draggable":'.esc_attr( $slider_dragable ).', "fade": false }';
        }

        if ( empty( $content_details ) ) {
            return;
        } ?>
        <section id="main-slider">
            <div class="regular" data-effect="<?php echo esc_attr( $slider_effect ); ?>" data-slick=<?php echo "'" . $data_slick_value . "'"; ?>>

                <?php foreach ($content_details as $content_detail ) : ?> 
                <div class="slider-item" style="background-image: url('<?php echo esc_url( $content_detail['img_array'][0] ); ?>')">
                    <a href="<?php echo esc_url( $content_detail['url'] ); ?>">
                    <div class="black-overlay"></div></a>
                    <div class="main-slider-contents">
                        <?php if( !empty( $content_detail['title'] ) ){ ?>
                            <h2 class="title"><a href="<?php echo esc_url( $content_detail['url'] ); ?>"><?php echo esc_html( $content_detail['title'] );?></a></h2> 
                        <?php }
                        if( !empty( $content_detail['content'] ) ){ ?>
                            <p><?php echo esc_html( $content_detail['content'] );?></p>
                        <?php } 
                            $learn_more_link = ( 'demo' == $content_type ) ? '#' : $content_detail['url'];

                        if( !empty( $read_more_button ) ) :
                        ?>
                        <a href="<?php echo esc_url( $learn_more_link ); ?>" class="btn btn-default"><?php echo esc_html( $read_more_button );?></a>
                        <?php endif; ?>
                    </div><!-- .main-slider-contents -->
                </div><!-- .slider-item -->
                <?php endforeach; ?>

            </div><!-- .regular -->
            <?php if( $slider_divider_enable ) : ?>
            <div class="divider">
                <img src="<?php echo get_template_directory_uri() .'/assets/uploads/slider-divider.png'; ?>" alt="<?php esc_attr_e( 'Slider divider', 'kids-education-pro' ); ?>">
            </div><!-- .divider -->
            <?php endif; ?>
        </section><!-- #main-slider -->       
<?php 
    }
endif;